===================
Text Representation
===================

Text representation commands are used to determine how objects are printed on the Python command line.

Object features
---------------

redentABQ
~~~~~~~~~

.. autoclass:: abaqus.TextRepresentation.redentABQ.redentABQ
    :members:

    .. autoclasstoc::

textRepr
~~~~~~~~

.. autoclass:: abaqus.TextRepresentation.textRepr.textRepr
    :members:

    .. autoclasstoc::

TextReprOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.TextRepresentation.TextReprOptions.TextReprOptions
    :members:

    .. autoclasstoc::

